from .json_数值数据查找 import json_数值数据查找
from .json_文本数据查找 import json_文本数据查找
from .json_精准_键_删除 import json_精准_键_删除
from .json_精准_键_取值 import json_精准_键_取值
from .json_精准_键_取路径 import json_精准_键_取路径
from .json_精准_键_重命名 import json_精准_键_重命名
from .json_遍历_值_取出现次数 import json_遍历_值_取出现次数
from .json_遍历_值_取路径 import json_遍历_值_取路径
from .json_遍历_值_取键名 import json_遍历_值_取键名
from .json_遍历_值_更新 import json_遍历_值_更新
from .json_遍历_键_删除 import json_遍历_键_删除
from .json_遍历_键_取值 import json_遍历_键_取值
from .json_遍历_键_取路径 import json_遍历_键_取路径
from .json_遍历_键_重命名 import json_遍历_键_重命名
from .json_遍历所有层级指定键 import json_遍历所有层级指定键
from .json_遍历所有层级获取路径 import json_遍历所有层级获取路径
from .json_遍历指定层级指定键 import json_遍历指定层级指定键


def mysql_更新_字段名(连接对象, 表名, 新字段名列表):
    """
    更新指定表的字段名，记住列表成员数量必须和MySQL表单字段数量一致才行。

    参数：
        - 连接对象：MySQL 数据库连接对象。
        - 表名：要更新字段名的表名称。
        - 新字段名列表：新的字段名称列表，依次更新字段名。

    返回值：
        - 更新成功返回 True，失败返回 False。
    """
    try:
        cursor = 连接对象.cursor()

        # 获取当前字段名称、类型、字符集和排序规则
        查询字段名语句 = f"SHOW FULL COLUMNS FROM {表名}"
        cursor.execute(查询字段名语句)
        结果 = cursor.fetchall()
        当前字段名列表 = [行[0] for 行 in 结果]

        # 检查新字段名列表长度是否匹配
        if len(当前字段名列表) != len(新字段名列表):
            print("新字段名列表长度与当前字段数量不匹配。")
            return False

        # 依次更新字段名
        for 行 in 结果:
            旧字段名 = 行[0]
            新字段名 = 新字段名列表[当前字段名列表.index(旧字段名)]
            字段类型 = 行[1]
            排序规则 = 行[2]  # 提取排序规则

            # 处理可能的排序规则
            if 排序规则 and not 排序规则.isdigit() and 排序规则 not in ['PRI', 'UNI', 'MUL']:
                更新字段名语句 = f"ALTER TABLE {表名} CHANGE `{旧字段名}` `{新字段名}` {字段类型} COLLATE {排序规则}"
            else:
                更新字段名语句 = f"ALTER TABLE {表名} CHANGE `{旧字段名}` `{新字段名}` {字段类型}"

            try:
                cursor.execute(更新字段名语句)
                print(f"字段名 '{旧字段名}' 成功更新为 '{新字段名}'")
            except Exception as e:
                print(f"更新字段 '{旧字段名}' 到 '{新字段名}' 失败: {e}")
                return False

        连接对象.commit()
        return True

    except Exception as e:
        print(f"发生错误: {e}")
        return False


def 模块_更新内容查看():
    分隔符 = "-" * 100
    版本颜色 = "\033[95m"  # 紫色
    内容颜色 = "\033[92m"  # 亮绿色
    重置颜色 = "\033[0m"

    更新内容 = f"""
{分隔符}
{版本颜色}版本号：1.0.172 ---- 2024年7月12日{重置颜色}
{内容颜色}新增命令：mysql_克隆表单_仅结构(连接对象,源表名,目标表名，#自动递增是否归重置>布尔型，可空<) -->返回一个布尔型：成功返回True，失败返回 False
新增命令：mysql_克隆表单_结构和数据(连接对象,源表名,目标表名)   -->返回一个布尔型：成功返回True，失败返回 False
新增命令：mysql_更新_字段名(连接对象,表名,新字段名列表)   -->返回一个布尔型：成功返回True，失败返回 False
新增命令：mysql_查询_表结构(连接对象,表名)  -->返回一个列表用于存储：结构信息，失败则返回空列表
新增命令：mysql_创建新表(连接对象,表名,结构信息)   -->返回一个布尔型：成功返回True，失败返回 False{重置颜色}
{分隔符}
{版本颜色}版本号：1.0.173 ---- 2024年7月12日{重置颜色}
{内容颜色}新增命令：模块_更新内容查看()    -->无需传递任何参数且没有返回值，默认打印每个版本更新的内容详情{重置颜色}
{分隔符}
{版本颜色}版本号：1.0.174 ---- 2024年7月13日{重置颜色}
{内容颜色}修复已知BUG{重置颜色}
{分隔符}
{版本颜色}版本号：1.0.175 ---- 2024年7月13日{重置颜色}
{内容颜色}修复命令：mysql_更新_字段名(连接对象,表名,新字段名列表)  字符集问题导致无法正常修改的情况{重置颜色}
{分隔符}
{版本颜色}版本号：1.0.176 ---- 2024年7月14日{重置颜色}
{内容颜色}新增命令：邮件IMAP_按日期和发件人搜索邮件(连接对象, 年(int), 月(int), 日(int), 发件人邮箱(str), 条件="SINCE")    -->最后的条件"SINCE"表示条件日期之后的，"BEFORE"表示取之前的
新增命令：邮件IMAP_按日期和主题搜索邮件(连接对象, 年(int), 月(int), 日(int), 主题(str), 条件="SINCE")    -->最后的条件"SINCE"表示条件日期之后的，"BEFORE"表示取之前的{重置颜色}
{分隔符}
{版本颜色}版本号：1.0.185 ---- 2024年7月14日{重置颜色}
{内容颜色}新增命令：
    进程_取命令行(pid)
    进程_取父ID(pid)
    进程_取程序路径(pid)
    进程_取线程数(pid)
    进程_取进程列表()
    进程_取进程启动时间(pid)
    进程_名取ID(进程名)
    进程_名取ID列表(进程名)
    进程_枚举()
    进程_结束PID(pid)
    进程_结束名(进程名){重置颜色}
{分隔符}
{版本颜色}版本号：1.1.0 ---- 2024年7月15日{重置颜色}
{内容颜色}本次更新属于较大调整，对模块内部板块进行调整，优化执行效率。
在保证老的全局调用方式可用的同时，增加独立调用特性。

全局调用使用示例：
import zfx
响应对象 = zfx.网页协议_发送_GET请求("www.baidu.com")
print(响应对象)

独立调用使用示例：
import zfx.网页协议 as 协议
响应对象 = 协议.网页协议_发送_GET请求("www.baidu.com")
print(响应对象){重置颜色}
{分隔符}
"""
    print(更新内容)



from .抛出异常_Exception import 抛出异常_Exception
from .抛出异常_AttributeError import 抛出异常_AttributeError
from .抛出异常_IndexError import 抛出异常_IndexError
from .抛出异常_KeyError import 抛出异常_KeyError
from .抛出异常_SyntaxError import 抛出异常_SyntaxError
from .抛出异常_TypeError import 抛出异常_TypeError
from .抛出异常_ValueError import 抛出异常_ValueError
from .抛出异常_ZeroDivisionError import 抛出异常_ZeroDivisionError
from .抛出异常_FileNotFoundError import 抛出异常_FileNotFoundError
from .抛出异常_OSError import 抛出异常_OSError
from .抛出异常_ImportError import 抛出异常_ImportError
from .抛出异常_ModuleNotFoundError import 抛出异常_ModuleNotFoundError


def mysql_克隆表单_仅结构(连接对象, 源表名, 目标表名, 自动递增是否重置=False):
    """
    仅复制源表的表结构到目标表。

    参数：
        - 连接对象：MySQL 数据库连接对象。
        - 源表名：要复制结构的源表名称。
        - 目标表名：目标表的名称。
        - 自动递增是否归重置：为真则重置为1，为假则保持原样，默认为假。

    返回值：
        - 克隆成功返回 True，失败返回 False。
    """
    try:
        cursor = 连接对象.cursor()

        # 查询源表的结构信息
        查询语句 = f"SHOW CREATE TABLE {源表名}"
        cursor.execute(查询语句)
        结果 = cursor.fetchone()

        # 提取创建表的语句
        创建语句 = 结果[1]

        # 替换表名为目标表名
        创建语句 = 创建语句.replace(源表名, 目标表名)

        # 执行创建表操作
        cursor.execute(创建语句)

        # 如果需要重置自动递增的值
        if 自动递增是否重置:
            重置语句 = f"ALTER TABLE {目标表名} AUTO_INCREMENT = 1"
            cursor.execute(重置语句)

        连接对象.commit()
        return True

    except Exception as e:
        return False


from .系统_取CPU型号 import 系统_取CPU型号
from .系统_取剪辑版内容 import 系统_取剪辑版内容
from .系统_取剪辑版内容到十六进制 import 系统_取剪辑版内容到十六进制
from .系统_取操作系统类别 import 系统_取操作系统类别
from .系统_取时区 import 系统_取时区
from .系统_取用户名 import 系统_取用户名
from .系统_取硬盘特征字 import 系统_取硬盘特征字
from .系统_取系统现行时间 import 系统_取系统现行时间
from .系统_强制关机 import 系统_强制关机
from .系统_强制注销 import 系统_强制注销
from .系统_强制重启 import 系统_强制重启
from .系统_是否为管理员 import 系统_是否为管理员
from .系统_是否已联网 import 系统_是否已联网
from .系统_清空回收站 import 系统_清空回收站
from .系统_生成随机mac import 系统_生成随机mac
from .系统_置剪辑版内容 import 系统_置剪辑版内容
from .系统_获取外网IP import 系统_获取外网IP
from .系统任务计划_删除 import 系统任务计划_删除
from .系统任务计划_遍历名称 import 系统任务计划_遍历名称


import psutil


def 进程_取程序路径(pid):
    """
    根据进程ID获取程序路径。

    参数:
        - pid (int): 要查询的进程ID。

    返回值:
        - str: 成功返回程序路径，失败返回空字符串。

    使用示例:
    程序路径 = 进程_取程序路径(1234)
    """
    try:
        process = psutil.Process(pid)
        return process.exe()
    except Exception as e:
        return ""


import psutil


def 进程_名取ID列表(进程名):
    """
    根据进程名称获取所有匹配的进程ID列表。

    参数:
        - 进程名 (str): 要查询的进程名称，包括后缀（例如：chrome.exe）。

    返回值:
        - list: 成功找到返回包含所有匹配进程ID的列表，失败返回空列表。

    使用示例:
    进程ID列表 = 进程_名取ID列表("chrome.exe")
    """
    try:
        pid_list = []
        # 遍历所有运行中的进程
        for proc in psutil.process_iter(['pid', 'name']):
            # 检查进程名称是否匹配
            if proc.info['name'] == 进程名:
                pid_list.append(proc.info['pid'])  # 将匹配的进程ID加入列表
        return pid_list  # 返回包含所有匹配进程ID的列表
    except Exception:
        return []  # 捕获所有异常并返回空列表


import psutil
import datetime


def 进程_取进程启动时间(pid):
    """
    根据进程ID获取进程的启动时间。

    参数:
        - pid (int): 要查询的进程ID。

    返回值:
        - str: 成功返回进程启动时间的字符串表示，失败返回空字符串。

    使用示例:
    启动时间 = 进程_取进程启动时间(1234)
    """
    try:
        process = psutil.Process(pid)
        start_time = process.create_time()
        return datetime.datetime.fromtimestamp(start_time).strftime("%Y-%m-%d %H:%M:%S")
    except Exception:
        return ""


from .文本文件_修改指定行内容 import 文本文件_修改指定行内容
from .文本文件_写入文件内容 import 文本文件_写入文件内容
from .文本文件_删除指定行 import 文本文件_删除指定行
from .文本文件_删除空行 import 文本文件_删除空行
from .文本文件_取关键词出现次数 import 文本文件_取关键词出现次数
from .文本文件_取指定行内容 import 文本文件_取指定行内容
from .文本文件_取指定行内容_分割 import 文本文件_取指定行内容_分割
from .文本文件_取指定行内容_取中间 import 文本文件_取指定行内容_取中间
from .文本文件_取指定行内容_取出现次数 import 文本文件_取指定行内容_取出现次数
from .文本文件_取指定行内容_取右边 import 文本文件_取指定行内容_取右边
from .文本文件_取指定行内容_取左边 import 文本文件_取指定行内容_取左边
from .文本文件_取指定行内容_取长度 import 文本文件_取指定行内容_取长度
from .文本文件_取行数 import 文本文件_取行数
from .文本文件_插入内容 import 文本文件_插入内容
from .文本文件_替换内容 import 文本文件_替换内容
from .文本文件_统计字符数 import 文本文件_统计字符数
from .文本文件_读入全部内容 import 文本文件_读入全部内容
from .文本文件_读入运行目录下文件内容 import 文本文件_读入运行目录下文件内容
from .文本文件_追加内容 import 文本文件_追加内容


from openpyxl.styles import Alignment


def excel_设置单元格格式(表格对象, 工作表名, 单元格, 对齐=None):
    """
    参数:
        - 表格对象: 要操作的表格对象
        - 工作表名: 要设置单元格格式的工作表名称
        - 单元格: 要设置格式的单元格坐标，例如 'A1'
        - 对齐: 对齐方式，可选值为 "左对齐"、"右对齐"、"居中对齐"

    返回值:
    - 如果成功设置单元格格式，则返回 True；如果设置失败，则返回 False，并打印错误信息
    """
    try:
        工作表 = 表格对象[工作表名]
        单元格对象 = 工作表[单元格]
        if 对齐:
            对齐方式 = {
                "左对齐": "left",
                "右对齐": "right",
                "居中对齐": "center"
            }
            if 对齐 in 对齐方式:
                单元格对象.alignment = Alignment(horizontal=对齐方式[对齐])
            else:
                print(f"无效的对齐方式: {对齐}")
                return False
        return True
    except Exception as e:
        print(f"设置单元格格式时发生错误: {e}")
        return False



from .模块_外部库卸载 import 模块_外部库卸载
from .模块_外部库安装 import 模块_外部库安装
from .模块_更新内容查看 import 模块_更新内容查看
from .模块_更新到指定版本 import 模块_更新到指定版本
from .模块_更新到指定版本2 import 模块_更新到指定版本2
from .模块_更新版本 import 模块_更新版本
from .模块_更新版本2 import 模块_更新版本2
from .模块_查看版本信息 import 模块_查看版本信息
from .模块_查看版本信息2 import 模块_查看版本信息2
from .模块_重置Winsock import 模块_重置Winsock


import os
import signal


def 进程_结束PID(pid):
    """
    尝试终止指定PID的进程。

    参数:
        - pid (int): 要终止的进程ID。

    返回值:
        - bool: 成功终止返回True，失败返回False。

    说明:
    该函数会尝试终止指定的进程ID。如果发生异常，会返回False。
    """
    try:
        # 将PID转换为整数并使用os.kill函数发送SIGTERM信号以终止进程
        os.kill(int(pid), signal.SIGTERM)
        return True
    except Exception:
        return False


from .谷歌填表_XPATH等待元素出现 import 谷歌填表_XPATH等待元素出现
from .谷歌填表_XPATH等待元素可点击 import 谷歌填表_XPATH等待元素可点击
from .谷歌填表_XPATH等待元素可见 import 谷歌填表_XPATH等待元素可见
from .谷歌填表_保存截图 import 谷歌填表_保存截图
from .谷歌填表_偏移点击 import 谷歌填表_偏移点击
from .谷歌填表_切换框架 import 谷歌填表_切换框架
from .谷歌填表_切换窗口 import 谷歌填表_切换窗口
from .谷歌填表_初始化 import 谷歌填表_初始化
from .谷歌填表_初始化2 import 谷歌填表_初始化2
from .谷歌填表_访问网页 import 谷歌填表_访问网页
from .谷歌填表_判断可用 import 谷歌填表_判断可用
from .谷歌填表_判断可见 import 谷歌填表_判断可见
from .谷歌填表_判断选中 import 谷歌填表_判断选中
from .谷歌填表_刷新 import 谷歌填表_刷新
from .谷歌填表_前进 import 谷歌填表_前进
from .谷歌填表_取当前页面网址 import 谷歌填表_取当前页面网址
from .谷歌填表_后退 import 谷歌填表_后退
from .谷歌填表_查找元素 import 谷歌填表_查找元素
from .谷歌填表_查找多个元素 import 谷歌填表_查找多个元素
from .谷歌填表_点击元素 import 谷歌填表_点击元素
from .谷歌填表_输入文本 import 谷歌填表_输入文本
from .谷歌填表_清除文本 import 谷歌填表_清除文本
from .谷歌填表_获取属性值 import 谷歌填表_获取属性值
from .谷歌填表_等待元素出现 import 谷歌填表_等待元素出现
from .谷歌填表_等待元素可见 import 谷歌填表_等待元素可见
from .谷歌填表_等待元素可点击 import 谷歌填表_等待元素可点击
from .谷歌填表_执行JavaScript import 谷歌填表_执行JavaScript
from .谷歌填表_获取页面源代码 import 谷歌填表_获取页面源代码
from .谷歌填表_模拟点击 import 谷歌填表_模拟点击


import sys
from . import excel
from .excel.excel_保存Excel文件 import excel_保存Excel文件
from .excel.excel_修改单元格 import excel_修改单元格
from .excel.excel_关闭Excel文件 import excel_关闭Excel文件
from .excel.excel_删除列 import excel_删除列
from .excel.excel_删除行 import excel_删除行
from .excel.excel_打开Excel文件 import excel_打开Excel文件
from .excel.excel_插入列 import excel_插入列
from .excel.excel_插入行 import excel_插入行
from .excel.excel_设置单元格格式 import excel_设置单元格格式
from .excel.excel_读取单元格 import excel_读取单元格
from . import html
from .html.html_提取所有a标签 import html_提取所有a标签
from .html.html_提取所有div标签 import html_提取所有div标签
from .html.html_提取所有li标签 import html_提取所有li标签
from .html.html_提取所有p标签 import html_提取所有p标签
from .html.html_提取所有span标签 import html_提取所有span标签
from .html.html_提取所有ul标签 import html_提取所有ul标签
from .html.html_提取所有图像 import html_提取所有图像
from .html.html_提取所有字典 import html_提取所有字典
from .html.html_提取所有指定标签 import html_提取所有指定标签
from .html.html_提取所有文本内容 import html_提取所有文本内容
from .html.html_提取所有标题 import html_提取所有标题
from .html.html_提取所有链接 import html_提取所有链接
from .html.html_通用查找 import html_通用查找
from .html.html_通用查找_多个属性 import html_通用查找_多个属性
from .html.html_通用查找_属性值匹配 import html_通用查找_属性值匹配
from .html.html_通用查找_标签和属性值匹配 import html_通用查找_标签和属性值匹配
from .html.html_通用查找_长度上限 import html_通用查找_长度上限
from .html.html_通用查找_长度下限 import html_通用查找_长度下限
from . import json
from .json.json_数值数据查找 import json_数值数据查找
from .json.json_文本数据查找 import json_文本数据查找
from .json.json_精准_键_删除 import json_精准_键_删除
from .json.json_精准_键_取值 import json_精准_键_取值
from .json.json_精准_键_取路径 import json_精准_键_取路径
from .json.json_精准_键_重命名 import json_精准_键_重命名
from .json.json_遍历_值_取出现次数 import json_遍历_值_取出现次数
from .json.json_遍历_值_取路径 import json_遍历_值_取路径
from .json.json_遍历_值_取键名 import json_遍历_值_取键名
from .json.json_遍历_值_更新 import json_遍历_值_更新
from .json.json_遍历_键_删除 import json_遍历_键_删除
from .json.json_遍历_键_取值 import json_遍历_键_取值
from .json.json_遍历_键_取路径 import json_遍历_键_取路径
from .json.json_遍历_键_重命名 import json_遍历_键_重命名
from .json.json_遍历所有层级指定键 import json_遍历所有层级指定键
from .json.json_遍历所有层级获取路径 import json_遍历所有层级获取路径
from .json.json_遍历指定层级指定键 import json_遍历指定层级指定键
from . import mysql
from .mysql.mysql_克隆表单_仅结构 import mysql_克隆表单_仅结构
from .mysql.mysql_克隆表单_结构和数据 import mysql_克隆表单_结构和数据
from .mysql.mysql_关闭连接 import mysql_关闭连接
from .mysql.mysql_创建新表 import mysql_创建新表
from .mysql.mysql_删除记录 import mysql_删除记录
from .mysql.mysql_增加_单条记录 import mysql_增加_单条记录
from .mysql.mysql_增加_增加记录 import mysql_增加_增加记录
from .mysql.mysql_增加_多条记录 import mysql_增加_多条记录
from .mysql.mysql_增加_记录不存在则添加 import mysql_增加_记录不存在则添加
from .mysql.mysql_执行SQL语句 import mysql_执行SQL语句
from .mysql.mysql_更新_SQL语句条件 import mysql_更新_SQL语句条件
from .mysql.mysql_更新_字典条件 import mysql_更新_字典条件
from .mysql.mysql_更新_字段名 import mysql_更新_字段名
from .mysql.mysql_更新_指定字段空值填充 import mysql_更新_指定字段空值填充
from .mysql.mysql_更新_清空字段数据 import mysql_更新_清空字段数据
from .mysql.mysql_更新_清空数据表 import mysql_更新_清空数据表
from .mysql.mysql_更新_置字段所有数据为Null import mysql_更新_置字段所有数据为Null
from .mysql.mysql_查询_取所有表名 import mysql_查询_取所有表名
from .mysql.mysql_查询_唯一值数量 import mysql_查询_唯一值数量
from .mysql.mysql_查询_字段值列表 import mysql_查询_字段值列表
from .mysql.mysql_查询_导出数据表 import mysql_查询_导出数据表
from .mysql.mysql_查询_最后一条记录 import mysql_查询_最后一条记录
from .mysql.mysql_查询_条件查找 import mysql_查询_条件查找
from .mysql.mysql_查询_条件查找_排序 import mysql_查询_条件查找_排序
from .mysql.mysql_查询_第一条记录 import mysql_查询_第一条记录
from .mysql.mysql_查询_获取列名 import mysql_查询_获取列名
from .mysql.mysql_查询_表结构 import mysql_查询_表结构
from .mysql.mysql_查询_表记录总数 import mysql_查询_表记录总数
from .mysql.mysql_查询_随机取出一条记录 import mysql_查询_随机取出一条记录
from .mysql.mysql_连接数据库 import mysql_连接数据库
from .mysql.mysql_连接数据库2 import mysql_连接数据库2
from . import 列表
from .列表.列表_交集 import 列表_交集
from .列表.列表_元素替换 import 列表_元素替换
from .列表.列表_全员乘法计算 import 列表_全员乘法计算
from .列表.列表_全员减法计算 import 列表_全员减法计算
from .列表.列表_全员加法计算 import 列表_全员加法计算
from .列表.列表_全员除法计算 import 列表_全员除法计算
from .列表.列表_去除前后空格 import 列表_去除前后空格
from .列表.列表_去除指定元素 import 列表_去除指定元素
from .列表.列表_去除空元素 import 列表_去除空元素
from .列表.列表_去除重复 import 列表_去除重复
from .列表.列表_反转 import 列表_反转
from .列表.列表_取元素出现次数 import 列表_取元素出现次数
from .列表.列表_取平均值 import 列表_取平均值
from .列表.列表_取成员索引 import 列表_取成员索引
from .列表.列表_取最大值 import 列表_取最大值
from .列表.列表_取最小值 import 列表_取最小值
from .列表.列表_并集 import 列表_并集
from .列表.列表_成员合并 import 列表_成员合并
from .列表.列表_按元素数量分组 import 列表_按元素数量分组
from .列表.列表_排序 import 列表_排序
from .列表.列表_插入元素 import 列表_插入元素
from .列表.列表_求和 import 列表_求和
from .列表.列表_移除偶数索引元素 import 列表_移除偶数索引元素
from .列表.列表_移除奇数索引元素 import 列表_移除奇数索引元素
from .列表.列表_筛选_关键词保留 import 列表_筛选_关键词保留
from .列表.列表_筛选_关键词过滤 import 列表_筛选_关键词过滤
from .列表.列表_筛选_最大长度过滤 import 列表_筛选_最大长度过滤
from .列表.列表_筛选_最小长度过滤 import 列表_筛选_最小长度过滤
from . import 常量
from . import 打印
from .打印.zprint import 打印_调试_开启
from .打印.zprint import 打印_调试_关闭
from .打印.zprint import 打印_调试_普通打印
from .打印.zprint import 打印_调试_强制打印
from .打印.打印_依次打印列表 import 打印_依次打印列表
from .打印.打印_依次打印字典 import 打印_依次打印字典
from .打印.打印_分隔线 import 打印_分隔线
from .打印.打印_字典所有值层级路径 import 打印_字典所有值层级路径
from .打印.打印_带标题打印列表 import 打印_带标题打印列表
from .打印.打印_带标题打印字典 import 打印_带标题打印字典
from .打印.打印_带索引打印列表 import 打印_带索引打印列表
from .打印.打印_打印JSON格式化 import 打印_打印JSON格式化
from .打印.打印_打印目录树 import 打印_打印目录树
from .打印.打印_打印进度条 import 打印_打印进度条
from . import 抛出异常
from .抛出异常.抛出异常_Exception import 抛出异常_Exception
from .抛出异常.抛出异常_AttributeError import 抛出异常_AttributeError
from .抛出异常.抛出异常_IndexError import 抛出异常_IndexError
from .抛出异常.抛出异常_KeyError import 抛出异常_KeyError
from .抛出异常.抛出异常_SyntaxError import 抛出异常_SyntaxError
from .抛出异常.抛出异常_TypeError import 抛出异常_TypeError
from .抛出异常.抛出异常_ValueError import 抛出异常_ValueError
from .抛出异常.抛出异常_ZeroDivisionError import 抛出异常_ZeroDivisionError
from .抛出异常.抛出异常_FileNotFoundError import 抛出异常_FileNotFoundError
from .抛出异常.抛出异常_OSError import 抛出异常_OSError
from .抛出异常.抛出异常_ImportError import 抛出异常_ImportError
from .抛出异常.抛出异常_ModuleNotFoundError import 抛出异常_ModuleNotFoundError
from . import 拓展功能
from . import 数据类型转换
from .数据类型转换.数据类型转换_到None import 数据类型转换_到None
from .数据类型转换.数据类型转换_到元组 import 数据类型转换_到元组
from .数据类型转换.数据类型转换_到列表 import 数据类型转换_到列表
from .数据类型转换.数据类型转换_到字典 import 数据类型转换_到字典
from .数据类型转换.数据类型转换_到字符串 import 数据类型转换_到字符串
from .数据类型转换.数据类型转换_到小数 import 数据类型转换_到小数
from .数据类型转换.数据类型转换_到布尔型 import 数据类型转换_到布尔型
from .数据类型转换.数据类型转换_到整数 import 数据类型转换_到整数
from .数据类型转换.数据类型转换_到逻辑型 import 数据类型转换_到逻辑型
from .数据类型转换.数据类型转换_到集合 import 数据类型转换_到集合
from . import 文件
from .文件.文件_删除文件 import 文件_删除文件
from .文件.文件_取大小B import 文件_取大小B
from .文件.文件_取大小KB import 文件_取大小KB
from .文件.文件_取大小MB import 文件_取大小MB
from .文件.文件_取大小GB import 文件_取大小GB
from .文件.文件_复制 import 文件_复制
from .文件.文件_封装Py代码成EXE_独立编译 import 文件_封装Py代码成EXE_独立编译
from .文件.文件_封装Py代码成EXE_普通编译 import 文件_封装Py代码成EXE_普通编译
from .文件.文件_文件是否存在 import 文件_文件是否存在
from .文件.文件_枚举 import 文件_枚举
from . import 文本
from .文本.文本_从中间往右取 import 文本_从中间往右取
from .文本.文本_从中间往左取 import 文本_从中间往左取
from .文本.文本_从右往左取 import 文本_从右往左取
from .文本.文本_从左往右取 import 文本_从左往右取
from .文本.文本_分割文本 import 文本_分割文本
from .文本.文本_到大写 import 文本_到大写
from .文本.文本_到小写 import 文本_到小写
from .文本.文本_加密 import 文本_加密
from .文本.文本_十六进制替换 import 文本_十六进制替换
from .文本.文本_去除指定字符串_首次出现 import 文本_去除指定字符串_首次出现
from .文本.文本_去除指定字符串_自定义位置 import 文本_去除指定字符串_自定义位置
from .文本.文本_去除指定字符串_末次出现 import 文本_去除指定字符串_末次出现
from .文本.文本_去除换行符 import 文本_去除换行符
from .文本.文本_去除空格 import 文本_去除空格
from .文本.文本_去除空格和换行符 import 文本_去除空格和换行符
from .文本.文本_取出中间文本 import 文本_取出中间文本
from .文本.文本_取出现次数 import 文本_取出现次数
from .文本.文本_取右边 import 文本_取右边
from .文本.文本_取左边 import 文本_取左边
from .文本.文本_取指定变量文本行 import 文本_取指定变量文本行
from .文本.文本_取文本所在行 import 文本_取文本所在行
from .文本.文本_取文本指定次数出现的位置 import 文本_取文本指定次数出现的位置
from .文本.文本_取文本最后出现的位置 import 文本_取文本最后出现的位置
from .文本.文本_取文本首次出现的位置 import 文本_取文本首次出现的位置
from .文本.文本_取行数 import 文本_取行数
from .文本.文本_取长度 import 文本_取长度
from .文本.文本_取随机字符 import 文本_取随机字符
from .文本.文本_取随机范围数字 import 文本_取随机范围数字
from .文本.文本_字符串替换 import 文本_字符串替换
from .文本.文本_替换行内容 import 文本_替换行内容
from .文本.文本_解密 import 文本_解密
from .文本.文本_颠倒 import 文本_颠倒
from .文本.文本区分_只取符号 import 文本区分_只取符号
from .文本.文本区分_只取汉字 import 文本区分_只取汉字
from .文本.文本区分_只取数字 import 文本区分_只取数字
from . import 文本文件
from .文本文件.文本文件_修改指定行内容 import 文本文件_修改指定行内容
from .文本文件.文本文件_写入文件内容 import 文本文件_写入文件内容
from .文本文件.文本文件_删除指定行 import 文本文件_删除指定行
from .文本文件.文本文件_删除空行 import 文本文件_删除空行
from .文本文件.文本文件_取关键词出现次数 import 文本文件_取关键词出现次数
from .文本文件.文本文件_取指定行内容 import 文本文件_取指定行内容
from .文本文件.文本文件_取指定行内容_分割 import 文本文件_取指定行内容_分割
from .文本文件.文本文件_取指定行内容_取中间 import 文本文件_取指定行内容_取中间
from .文本文件.文本文件_取指定行内容_取出现次数 import 文本文件_取指定行内容_取出现次数
from .文本文件.文本文件_取指定行内容_取右边 import 文本文件_取指定行内容_取右边
from .文本文件.文本文件_取指定行内容_取左边 import 文本文件_取指定行内容_取左边
from .文本文件.文本文件_取指定行内容_取长度 import 文本文件_取指定行内容_取长度
from .文本文件.文本文件_取行数 import 文本文件_取行数
from .文本文件.文本文件_插入内容 import 文本文件_插入内容
from .文本文件.文本文件_替换内容 import 文本文件_替换内容
from .文本文件.文本文件_统计字符数 import 文本文件_统计字符数
from .文本文件.文本文件_读入全部内容 import 文本文件_读入全部内容
from .文本文件.文本文件_读入运行目录下文件内容 import 文本文件_读入运行目录下文件内容
from .文本文件.文本文件_追加内容 import 文本文件_追加内容
from . import 模块
from .模块.模块_外部库卸载 import 模块_外部库卸载
from .模块.模块_外部库安装 import 模块_外部库安装
from .模块.模块_更新内容查看 import 模块_更新内容查看
from .模块.模块_更新到指定版本 import 模块_更新到指定版本
from .模块.模块_更新到指定版本2 import 模块_更新到指定版本2
from .模块.模块_更新版本 import 模块_更新版本
from .模块.模块_更新版本2 import 模块_更新版本2
from .模块.模块_查看版本信息 import 模块_查看版本信息
from .模块.模块_查看版本信息2 import 模块_查看版本信息2
from .模块.模块_重置Winsock import 模块_重置Winsock
from . import 目录
from .目录.目录_创建 import 目录_创建
from .目录.目录_取system32目录 import 目录_取system32目录
from .目录.目录_取子目录数 import 目录_取子目录数
from .目录.目录_取桌面目录 import 目录_取桌面目录
from .目录.目录_取运行目录 import 目录_取运行目录
from .目录.目录_强力清空 import 目录_强力清空
from .目录.目录_枚举子目录 import 目录_枚举子目录
from . import 算数
from .算数.算数_保留小数点后指定位数 import 算数_保留小数点后指定位数
from .算数.算数_取绝对值 import 算数_取绝对值
from .算数.算数_向上取整 import 算数_向上取整
from .算数.算数_向下取整 import 算数_向下取整
from .算数.算数_四舍五入 import 算数_四舍五入
from .算数.算数_求中位数 import 算数_求中位数
from .算数.算数_求余弦 import 算数_求余弦
from .算数.算数_求余弧度 import 算数_求余弧度
from .算数.算数_求余数 import 算数_求余数
from .算数.算数_求反正切 import 算数_求反正切
from .算数.算数_求和 import 算数_求和
from .算数.算数_求对数 import 算数_求对数
from .算数.算数_求幂 import 算数_求幂
from .算数.算数_求平均值 import 算数_求平均值
from .算数.算数_求平方根 import 算数_求平方根
from .算数.算数_求最大公约数 import 算数_求最大公约数
from .算数.算数_求最小公倍数 import 算数_求最小公倍数
from .算数.算数_求标准差 import 算数_求标准差
from .算数.算数_求次方 import 算数_求次方
from .算数.算数_求正切 import 算数_求正切
from .算数.算数_求正弦 import 算数_求正弦
from .算数.算数_求阶乘 import 算数_求阶乘
from . import 系统
from .系统.系统_取CPU型号 import 系统_取CPU型号
from .系统.系统_取剪辑版内容 import 系统_取剪辑版内容
from .系统.系统_取剪辑版内容到十六进制 import 系统_取剪辑版内容到十六进制
from .系统.系统_取操作系统类别 import 系统_取操作系统类别
from .系统.系统_取时区 import 系统_取时区
from .系统.系统_取用户名 import 系统_取用户名
from .系统.系统_取硬盘特征字 import 系统_取硬盘特征字
from .系统.系统_取系统现行时间 import 系统_取系统现行时间
from .系统.系统_强制关机 import 系统_强制关机
from .系统.系统_强制注销 import 系统_强制注销
from .系统.系统_强制重启 import 系统_强制重启
from .系统.系统_是否为管理员 import 系统_是否为管理员
from .系统.系统_是否已联网 import 系统_是否已联网
from .系统.系统_清空回收站 import 系统_清空回收站
from .系统.系统_生成随机mac import 系统_生成随机mac
from .系统.系统_置剪辑版内容 import 系统_置剪辑版内容
from .系统.系统_获取外网IP import 系统_获取外网IP
from .系统.系统任务计划_删除 import 系统任务计划_删除
from .系统.系统任务计划_遍历名称 import 系统任务计划_遍历名称
from . import 线程
from .线程.线程_创建新线程 import 线程_创建新线程
from .线程.线程_取当前线程标识符 import 线程_取当前线程标识符
from .线程.线程_取当前线程名称 import 线程_取当前线程名称
from .线程.线程_取当前线程对象 import 线程_取当前线程对象
from .线程.线程_等待所有线程完成 import 线程_等待所有线程完成
from . import 编码
from .编码.编码_ASCII编码 import 编码_ASCII编码
from .编码.编码_ASCII解码 import 编码_ASCII解码
from .编码.编码_BASE64编码 import 编码_BASE64编码
from .编码.编码_BASE64解码 import 编码_BASE64解码
from .编码.编码_CRC32 import 编码_CRC32
from .编码.编码_Hex编码 import 编码_Hex编码
from .编码.编码_Hex解码 import 编码_Hex解码
from .编码.编码_HTML编码 import 编码_HTML编码
from .编码.编码_HTML解码 import 编码_HTML解码
from .编码.编码_MD5哈希 import 编码_MD5哈希
from .编码.编码_Rot13编码 import 编码_Rot13编码
from .编码.编码_SHA1哈希 import 编码_SHA1哈希
from .编码.编码_SHA256哈希 import 编码_SHA256哈希
from .编码.编码_SHA512哈希 import 编码_SHA512哈希
from .编码.编码_URL编码 import 编码_URL编码
from .编码.编码_URL解码 import 编码_URL解码
from .编码.编码_Unicode编码 import 编码_Unicode编码
from .编码.编码_Unicode解码 import 编码_Unicode解码
from .编码.编码_UTF8编码 import 编码_UTF8编码
from .编码.编码_UTF8解码 import 编码_UTF8解码
from .编码.编码_UTF32编码 import 编码_UTF32编码
from .编码.编码_UTF32解码 import 编码_UTF32解码
from .编码.编码_ZFX编码 import 编码_ZFX编码
from .编码.编码_ZFX解码 import 编码_ZFX解码
from .编码.编码_十六进制文本到字符串 import 编码_十六进制文本到字符串
from .编码.编码_字符串到十六进制文本 import 编码_字符串到十六进制文本
from .编码.编码_字符串到十六进制文本_原文备注 import 编码_字符串到十六进制文本_原文备注
from .编码.编码_字符串到十六进制文本_重点突出 import 编码_字符串到十六进制文本_重点突出
from .编码.编码_字符串到十六进制文本_重点突出2 import 编码_字符串到十六进制文本_重点突出2
from .编码.编码_字符串到十六进制文本_重点突出3 import 编码_字符串到十六进制文本_重点突出3
from . import 网页协议
from .网页协议.网页协议_发送_GET请求 import 网页协议_发送_GET请求
from .网页协议.网页协议_发送_GET请求_取响应文本 import 网页协议_发送_GET请求_取响应文本
from .网页协议.网页协议_发送_GET请求_防检测 import 网页协议_发送_GET请求_防检测
from .网页协议.网页协议_发送_POST请求 import 网页协议_发送_POST请求
from .网页协议.网页协议_响应对象_到十六进制 import 网页协议_响应对象_到十六进制
from .网页协议.网页协议_响应对象_去除换行符 import 网页协议_响应对象_去除换行符
from .网页协议.网页协议_响应对象_取中间 import 网页协议_响应对象_取中间
from .网页协议.网页协议_响应对象_取右边 import 网页协议_响应对象_取右边
from .网页协议.网页协议_响应对象_取左边 import 网页协议_响应对象_取左边
from .网页协议.网页协议_响应对象_取指定行内容 import 网页协议_响应对象_取指定行内容
from .网页协议.网页协议_响应对象_取行数 import 网页协议_响应对象_取行数
from .网页协议.网页协议_响应文本_到十六进制 import 网页协议_响应文本_到十六进制
from .网页协议.网页协议_响应文本_去除换行符 import 网页协议_响应文本_去除换行符
from .网页协议.网页协议_响应文本_取中间 import 网页协议_响应文本_取中间
from .网页协议.网页协议_响应文本_取右边 import 网页协议_响应文本_取右边
from .网页协议.网页协议_响应文本_取左边 import 网页协议_响应文本_取左边
from .网页协议.网页协议_响应文本_取指定行内容 import 网页协议_响应文本_取指定行内容
from .网页协议.网页协议_响应文本_取行数 import 网页协议_响应文本_取行数
from .网页协议.网页协议_图片下载 import 网页协议_图片下载
from .网页协议.网页协议_获取_HTTP状态码 import 网页协议_获取_HTTP状态码
from .网页协议.网页协议_获取_响应cookies import 网页协议_获取_响应cookies
from .网页协议.网页协议_获取_响应URL import 网页协议_获取_响应URL
from .网页协议.网页协议_获取_响应二进制内容 import 网页协议_获取_响应二进制内容
from .网页协议.网页协议_获取_响应头 import 网页协议_获取_响应头
from .网页协议.网页协议_获取_响应文本 import 网页协议_获取_响应文本
from .网页协议.网页协议_获取_响应编码 import 网页协议_获取_响应编码
from . import 谷歌填表
from .谷歌填表.谷歌填表_XPATH等待元素出现 import 谷歌填表_XPATH等待元素出现
from .谷歌填表.谷歌填表_XPATH等待元素可点击 import 谷歌填表_XPATH等待元素可点击
from .谷歌填表.谷歌填表_XPATH等待元素可见 import 谷歌填表_XPATH等待元素可见
from .谷歌填表.谷歌填表_保存截图 import 谷歌填表_保存截图
from .谷歌填表.谷歌填表_偏移点击 import 谷歌填表_偏移点击
from .谷歌填表.谷歌填表_切换框架 import 谷歌填表_切换框架
from .谷歌填表.谷歌填表_切换窗口 import 谷歌填表_切换窗口
from .谷歌填表.谷歌填表_初始化 import 谷歌填表_初始化
from .谷歌填表.谷歌填表_初始化2 import 谷歌填表_初始化2
from .谷歌填表.谷歌填表_访问网页 import 谷歌填表_访问网页
from .谷歌填表.谷歌填表_判断可用 import 谷歌填表_判断可用
from .谷歌填表.谷歌填表_判断可见 import 谷歌填表_判断可见
from .谷歌填表.谷歌填表_判断选中 import 谷歌填表_判断选中
from .谷歌填表.谷歌填表_刷新 import 谷歌填表_刷新
from .谷歌填表.谷歌填表_前进 import 谷歌填表_前进
from .谷歌填表.谷歌填表_取当前页面网址 import 谷歌填表_取当前页面网址
from .谷歌填表.谷歌填表_后退 import 谷歌填表_后退
from .谷歌填表.谷歌填表_查找元素 import 谷歌填表_查找元素
from .谷歌填表.谷歌填表_查找多个元素 import 谷歌填表_查找多个元素
from .谷歌填表.谷歌填表_点击元素 import 谷歌填表_点击元素
from .谷歌填表.谷歌填表_输入文本 import 谷歌填表_输入文本
from .谷歌填表.谷歌填表_清除文本 import 谷歌填表_清除文本
from .谷歌填表.谷歌填表_获取属性值 import 谷歌填表_获取属性值
from .谷歌填表.谷歌填表_等待元素出现 import 谷歌填表_等待元素出现
from .谷歌填表.谷歌填表_等待元素可见 import 谷歌填表_等待元素可见
from .谷歌填表.谷歌填表_等待元素可点击 import 谷歌填表_等待元素可点击
from .谷歌填表.谷歌填表_执行JavaScript import 谷歌填表_执行JavaScript
from .谷歌填表.谷歌填表_获取页面源代码 import 谷歌填表_获取页面源代码
from .谷歌填表.谷歌填表_模拟点击 import 谷歌填表_模拟点击
from . import 进制转换
from .进制转换.进制转换_二进制转三十二进制 import 进制转换_二进制转三十二进制
from .进制转换.进制转换_二进制转八进制 import 进制转换_二进制转八进制
from .进制转换.进制转换_二进制转六十四进制 import 进制转换_二进制转六十四进制
from .进制转换.进制转换_二进制转十六进制 import 进制转换_二进制转十六进制
from .进制转换.进制转换_二进制转十进制 import 进制转换_二进制转十进制
from .进制转换.进制转换_十六进制转二进制 import 进制转换_十六进制转二进制
from .进制转换.进制转换_十六进制转八进制 import 进制转换_十六进制转八进制
from .进制转换.进制转换_十六进制转十进制 import 进制转换_十六进制转十进制
from .进制转换.进制转换_十进制转三十二进制 import 进制转换_十进制转三十二进制
from .进制转换.进制转换_十进制转二进制 import 进制转换_十进制转二进制
from .进制转换.进制转换_十进制转八进制 import 进制转换_十进制转八进制
from .进制转换.进制转换_十进制转六十四进制 import 进制转换_十进制转六十四进制
from .进制转换.进制转换_十进制转十六进制 import 进制转换_十进制转十六进制
from . import 进程
from .进程.进程_取命令行 import 进程_取命令行
from .进程.进程_取父ID import 进程_取父ID
from .进程.进程_取程序路径 import 进程_取程序路径
from .进程.进程_取线程数 import 进程_取线程数
from .进程.进程_取进程列表 import 进程_取进程列表
from .进程.进程_取进程启动时间 import 进程_取进程启动时间
from .进程.进程_名取ID import 进程_名取ID
from .进程.进程_名取ID列表 import 进程_名取ID列表
from .进程.进程_枚举 import 进程_枚举
from .进程.进程_结束PID import 进程_结束PID
from .进程.进程_结束名 import 进程_结束名
from . import 邮件IMAP
from .邮件IMAP.邮件IMAP_删除邮件 import 邮件IMAP_删除邮件
from .邮件IMAP.邮件IMAP_按主题搜索邮件 import 邮件IMAP_按主题搜索邮件
from .邮件IMAP.邮件IMAP_按发件人搜索邮件 import 邮件IMAP_按发件人搜索邮件
from .邮件IMAP.邮件IMAP_按日期和主题搜索邮件 import 邮件IMAP_按日期和主题搜索邮件
from .邮件IMAP.邮件IMAP_按日期和发件人搜索邮件 import 邮件IMAP_按日期和发件人搜索邮件
from .邮件IMAP.邮件IMAP_按日期搜索邮件 import 邮件IMAP_按日期搜索邮件
from .邮件IMAP.邮件IMAP_搜索邮件 import 邮件IMAP_搜索邮件
from .邮件IMAP.邮件IMAP_标记已读 import 邮件IMAP_标记已读
from .邮件IMAP.邮件IMAP_标记未读 import 邮件IMAP_标记未读
from .邮件IMAP.邮件IMAP_检查连接状态 import 邮件IMAP_检查连接状态
from .邮件IMAP.邮件IMAP_登出邮箱 import 邮件IMAP_登出邮箱
from .邮件IMAP.邮件IMAP_登录邮箱 import 邮件IMAP_登录邮箱
from .邮件IMAP.邮件IMAP_移动邮件 import 邮件IMAP_移动邮件
from .邮件IMAP.邮件IMAP_获取完整邮件 import 邮件IMAP_获取完整邮件
from .邮件IMAP.邮件IMAP_获取文件夹列表 import 邮件IMAP_获取文件夹列表
from .邮件IMAP.邮件IMAP_获取邮件头部 import 邮件IMAP_获取邮件头部
from .邮件IMAP.邮件IMAP_获取邮件正文 import 邮件IMAP_获取邮件正文
from .邮件IMAP.邮件IMAP_连接服务器 import 邮件IMAP_连接服务器
from .邮件IMAP.邮件IMAP_选择邮箱文件夹 import 邮件IMAP_选择邮箱文件夹
from . import 邮件POP3
from .邮件POP3.邮件POP3_删除邮件 import 邮件POP3_删除邮件
from .邮件POP3.邮件POP3_批量删除邮件 import 邮件POP3_批量删除邮件
from .邮件POP3.邮件POP3_断开连接 import 邮件POP3_断开连接
from .邮件POP3.邮件POP3_登录 import 邮件POP3_登录
from .邮件POP3.邮件POP3_获取最新一封邮件 import 邮件POP3_获取最新一封邮件
from .邮件POP3.邮件POP3_获取最新五封邮件 import 邮件POP3_获取最新五封邮件
from .邮件POP3.邮件POP3_获取最新十封邮件 import 邮件POP3_获取最新十封邮件
from .邮件POP3.邮件POP3_获取邮件内容 import 邮件POP3_获取邮件内容
from .邮件POP3.邮件POP3_获取邮件数量 import 邮件POP3_获取邮件数量
from .邮件POP3.邮件POP3_获取邮箱占用空间 import 邮件POP3_获取邮箱占用空间

